#
# Python script to create a windows distribution,
# currently a gzipped tar file.  I had a
# fancy installer but (i) it required a separate
# 23Mb download for the .NET framework and (ii) it
# probably wouldn't have run at GA anyway.
#


# convenience function for building file list
import os
def DLLFiles( directory, list ):
    return [ os.sep.join( [directory, XXX+'.dll'] ) for XXX in list ]


#---- NAME ------------------------------------------------------------

from datetime import datetime
distro = datetime.today().strftime('distro%Y%m%d.tgz')


  
#---- LOCAL DEPENDENCIES ----------------------------------------------

# local directories
localrootdir = '..'
localbindir = localrootdir + os.sep + 'bin'

# local files
localdlls = DLLFiles( localbindir, ['swwreader'] )
localfiles = [ os.sep.join( [localbindir, XXX] ) for XXX in \
               ['swollen.exe',     # the executable
                'sky_small.jpg',   # sky texture
                'envmap.jpg',      # water surface environment map
                'bedslope.jpg']]   # surface texture

localfiles.append(localrootdir + os.sep + 'data' + os.sep +
                  'laminar.sww')   # sample sww file for testing


#----- NETCDF DEPENDENCIES --------------------------------------------

# netcdf directory
netcdfdir = os.environ['NETCDF_DIR']

# netcdf DLL
netcdfdll = os.sep.join( [netcdfdir, 'bin', 'netcdf.dll'] )



#----- OSG DEPENDENCIES -----------------------------------------------

# OSG directories
osgrootdir = os.environ['OSG_ROOT']
osgdir = os.sep.join( [osgrootdir,'OpenSceneGraph','bin'] )
producerdir = os.sep.join( [osgrootdir,'Producer','bin'] )
openthreadsdir = os.sep.join( [osgrootdir,'OpenThreads','bin','win32'] )

# OSG/Producer/OpenThreads DLLs
producerdll = DLLFiles( producerdir, ['Producer'] )
openthreadsdll = DLLFiles( openthreadsdir, ['OpenThreadsWin32'] )
osgdlls = DLLFiles( osgdir, ['osg', 'osgdb', 'osgGA', 'osgProducer', 'osgText', 'osgUtil'] )

# supported database loaders (osgdb_XXX.dll)
osgimgformats = [ 'osgdb_'+XXX for XXX in ['jpeg', 'png', 'tiff', 'freetype'] ]
osgimgdlls = DLLFiles( osgdir, osgimgformats )

# All OSG DLLs
osgdlls = producerdll + openthreadsdll + osgdlls + osgimgdlls



#------ VISUAL STUDIO DEPENDENCIES ------------------------------------

# Visual Studio runtime directory
vsdir = os.environ['SYSTEMROOT'] + os.sep + 'system32'

# DLLs
vsdlls = DLLFiles( vsdir, ['msvcp71', 'msvcr71'] )



#------ ARCHIVE -------------------------------------------------------

# all files above
files = localfiles + localdlls + osgdlls + [netcdfdll] + vsdlls
files.sort()

import tarfile
import os.path
print "creating tgz archive %s" % distro
t = tarfile.open( distro, 'w:gz' )
for f in files:
    basename = os.path.basename(f)
    print "\tadding %s" % basename
    t.add( f, basename )
t.close()

